@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import secrets
 from pathlib import Path
 
@@ -7,8 +9,8 @@ from dotenv import set_key
 from rich import print as rich_print
 from rich.prompt import Prompt
 
-from ..utils import RICH_SUCCESS_MARKER
 from ..utils import get_current_dir_as_project_name
+from ..utils import RICH_SUCCESS_MARKER
 
 __all__ = ["write_env_file"]
 
@@ -33,7 +35,6 @@ def write_env_file(
         hide_input=True,
         help="Prompt for the postgres password to use to build the DATABASE_URL.",
     ),
-    # fixme change this db_name
     project_name: str = typer.Argument(
         "", callback=get_current_dir_as_project_name, hidden=True
     ),
